% Aluminium:
% E = 72 GPa, nu=1/3, rho=2.7 g/cm3
% c11=108, c12=54, c66=27
% Vl= 6.325... Vt=3.162....

% Water:
% rho=1.0 g/cm3
% c11=2.25, c12=2.25, c66=0
% Vl= 1.5
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

IsScatterer=0;  % 1 for scatterer, 0 for reference simulation

%% %%%%%%%%%%%%% Simulations parameters %%%%%%%%%%%


% signal
f0=1.0; % MHz
duration=4; %s
t0=duration/2;
bw=1;
CFL_coeff=0.99;

% media
Vscatterer=6.325; %mm/us
Vbackground=1.5; %mm/us
disk_diameter_mm=2.35;

Dimension1_mm=25;
Dimension2_mm=25;

% simulation grid step
grid_step_mm=0.025;

% circular receivers
radius_mm=12;
N_receivers=128;
theta=linspace(0,2*pi,N_receivers+1);
theta=theta(1:end-1);

% various derived parameters
ka_background=2*pi*f0/Vbackground*disk_diameter_mm/2;
ka_scatterer=2*pi*f0/Vscatterer*disk_diameter_mm/2;
lambda_scatterer=Vscatterer/f0;
lambda_background=Vbackground/f0;
Nb_pts_per_wavelength=lambda_background/grid_step_mm;
N1=Dimension1_mm/grid_step_mm+1;
N2=Dimension2_mm/grid_step_mm+1;
disk_diameter_pt=disk_diameter_mm/grid_step_mm+1;
Vmax=Vscatterer;
lambda_scatterer=Vscatterer/f0;
lambda_background=Vbackground/f0;
Nb_pts_per_wavelength=lambda_background/grid_step_mm;
N1=Dimension1_mm/grid_step_mm+1;
N2=Dimension2_mm/grid_step_mm+1;
disk_diameter_pt=disk_diameter_mm/grid_step_mm+1;

%% %%%%%%% geometry construction %%%%%%%%%%%%%%%%

geometry=repmat(uint8(0), N1, N2);

if IsScatterer % add the cylindrical scatterer to the geometry
    SE = strel('disk', (disk_diameter_pt+1)/2,0);
    scatterer = getnhood(SE);
    scatterer= scatterer(2:end-1,2:end-1);
    [M1,M2]=size(scatterer);
    geometry((N1-M1)/2+1:(N1+M1)/2,(N2-M2)/2+1:(N2+M2)/2)=scatterer;
end

figure(1)
imagesc(geometry);axis image
SimSonic2DWriteMap2D(geometry)

%% %%%%%%%%%% Signal construction %%%%%%%%%%%

temporal_step_us=CFL_coeff*grid_step_mm/(sqrt(2)*Vmax);

timebase=(0:temporal_step_us:duration);

[signalI,signalQ]=gauspuls(timebase-t0,f0,bw);signal=signalQ;
signal=signal'/max(signal);

figure(2)
plot(timebase,signal,'.-')
SimSonic2DWriteSgl(signal)

